pub const BOOTLOADER_HELLO_EVENT_CODE: u16 = 0x0000;

pub const PROGRAMMER_HELLO_EVENT_CODE: u16 = 0x0001;
pub const PROGRAMMER_START_FIRMWARE_UPGRADE_EVENT_CODE: u16 = 0x0002;

pub const ACK_EVENT_CODE: u16 = 0x0003;
pub const DATA_EVENT_CODE: u16 = 0x0004;

pub const CONFIGURATOR_HELLO_EVENT_CODE: u16 = 0x0005;

pub const BCM_CHANGE_BRIGHTNESS_EVENT_CODE: u16 = 0x0006;

pub const BUTTON_PRESSED_EVENT_CODE: u16 = 0x0007;
pub const BUTTON_RELEASED_EVENT_CODE: u16 = 0x0008;

pub const INTERNAL_SYSTEM_TICK_EVENT_CODE: u16 = 0x0009;

pub const PROGRAMMER_START_CONFIG_UPGRADE_EVENT_CODE: u16 = 0x000a;
pub const PROGRAMMER_SET_DEVICE_ADDRESS_EVENT_CODE: u16 = 0x000b;

pub const MESSAGE_EVENT_CODE: u16 = 0x000c;

pub const BCM_ANIMATE_BRIGHTNESS_EVENT_CODE: u16 = 0x000d;

pub const RELAY_SET_STATE_EVENT_CODE: u16 = 0x000e;
pub const RELAY_FLIP_STATE_EVENT_CODE: u16 = 0x000f;
